@@ -41,15 +41,18 @@ use XAO::Utils;
 use XAO::Objects;
 use base XAO::Objects->load(objname => 'Web::Page');
 
+use vars qw($VERSION);
+($VERSION)=(q$Id: Action.pm,v 1.2 2002/01/04 02:13:23 am Exp $ =~ /(\d+\.\d+)/);
+
 ##
 # Just calls check_mode if it is available. Everyting else is the
 # same as for Page.
 #
-sub display ($;%)
-{ my $self=shift;
-  my $args=get_args(\@_);
-  return $self->check_mode($args) if $self->can('check_mode');
-  $self->SUPER::display($args);
+sub display ($;%) {
+    my $self=shift;
+    my $args=get_args(\@_);
+    return $self->check_mode($args) if $self->can('check_mode');
+    $self->SUPER::display($args);
 }
 
 ###############################################################################
